#!/etc/opt/openit/perl -w
#
# $Id: psm.dm,v 1.17 2001/11/01 15:49:53 borgar Exp $
#
# (C) Copyright 2005 by Open Systems Computing AS, All rights reserved.
#
# This software may be used or copied only with the written permission of
# Open Systems Computing AS or in accordance with the terms and conditions
# stipulated in the agreement under which this software has been supplied.
#
# This file is part of Open iT Resources.
#
#HEAD##########################################################################
#
# @NAME:
#   s1188
# @AUTHOR:
#   Kjetil Yri
# @CREATED:
#   Mon Jan 17 11:51:58 MET 2005
# @DESCRIPTION:
#   Convert old and buggy license report jobs to new, corect ones.
#
#/HEAD#########################################################################

#MAIN##########################################################################
#
# @HEADING Main Description goes here
#
# Remeber to document program. You can use @LINK="to other doc" and
# include images @IMG="my.image" in the document.
#
#/MAIN#########################################################################

BEGIN {
    push @INC, "/opt/openit/contrib/lib";
}

use strict;

use     OpeniT::Contrib::Config;

my $config = new OpeniT::Contrib::Config;
$config->read("/etc/opt/openit/openit.cfg");

my $cron_dir = $config->{ "CRON_DIR" };
my @dirs = ( "D", "W", "M", "Q", "Y" );

my @files = ();
foreach my $dir( @dirs ) {
    if( ! opendir( DIR, "$cron_dir/$dir" ) ) {
	print "Could not read $dir directory";
	next;
    }
    my @basenames = grep !/^\.\.?\z/, readdir DIR;
    foreach my $basename( @basenames ) {
	push @files, "$cron_dir/$dir/$basename";
    }
    close( DIR );
}

foreach my $file( @files ) {
    if( ! open( FILE, "<$file" ) ) {
	print "Could not open for reading: $file\n";
	next;
    }
    $! = undef;
    my @lines = <FILE>;
    if( $! ) {
	print "Could not read: $file - $!\n";
	close( FILE );
	next;
    }
    if( ! close( FILE ) ) {
	print "Could not close: $file - $!\n";
	next;
    }
    my $acc_type = undef;
    my $text;
    foreach my $line( @lines ) {
	if( $line !~ m/^(#.*|\s*)$/ && ! defined $acc_type) {
	    $acc_type = $line;
	    chomp $acc_type;
	} elsif( $line !~ m/^(#.*|\s*)$/ && defined $acc_type ) {
	    $text = $line;
	    chomp $text;
	    last;
	}
    }

    my $wwwui = undef;
    foreach my $line( @lines ) {
	if( $line =~ m/--accvar \S+ / ) {
	    $wwwui = $line;
	    last;
	}
    }

    my $wwwui2 = _modify( $acc_type, $wwwui, $text );
    if( $wwwui eq $wwwui2 ) {
	next;
    }

    if( ! open( FILE, ">$file.tmp" ) ) {
	print "Could not open for write periodic report with title: $text";
	next;
    }

    my $wwwui_written = 0;
    my $failed = 0;
    foreach my $line( @lines ) {
	if( $line =~ m/--accvar \S+ / && ! $wwwui_written ) {
	    $line = $wwwui2;
	    $wwwui_written = 1;
	}
	if( ! print FILE $line ) {
	    print "Could not write report: $text\n";
	    close( FILE );
	    unlink( $file . ".tmp" );
	    $failed = 1;
	    last;
	}
    }

    if( ! $failed ) {
	if( ! close( FILE ) ) {
	    print "Could not close report with title: $text\n";
	    unlink( $file . ".tmp" );
	} else {
	    rename( $file . ".tmp", $file );
	}
    }
}

#SUB###########################################################################
#
# @NAME:
#   _modify
# @PURPOSE:
#   
# @ARGS:
#   none
# @RETURNS:
#   nothing
# @NOTE:
#   nothing
#
#/SUB#

sub _modify {
    my( $acc_type, $wwwui, $text ) = @_;

    my $index;
    if( $acc_type =~ m/^(43|44|62)$/ ) {
	$index = 2;
    } elsif( $acc_type =~ m/^(45|46|47|49|60|61|71|72)$/ ) {
	$index = 3;
    }

    if( ! defined $index ) {
	return $wwwui;
    }

    my @classvars;
    my $classvars;
    my $new_index = 4;
    if( $wwwui =~ m/--classvars (\S+) / ) {
	$classvars = $1;
	@classvars = split ":", $classvars;
	if( $classvars[ $index ] ne "[]" ) {
	    return $wwwui;# feature version selected, don't remove it after all
	}
	for( my $i = 0; $i < $index; $i++ ) {
	    if( $classvars[ $i ] ne "x" ) {
		$new_index++;
	    }
	}
    } else {
	print "Unable to convert chart report with title: $text\n";
	return $wwwui;
    }

    my $wwwui2 = $wwwui;
    my $class;
    if( $wwwui2 =~ m/--accvar \S+ (\S+) / ) {
	$class = $1;
	if( $class =~ m/^[0-9,]+$/ ) {
	    if( $wwwui2 =~ m/--vertical (\S+)/ ) {
		$class = $1;
		if( $wwwui2 =~ m/--horizontal (\S+)/ ) {
		    $class .= ",$1";
		}
	    }
	}
	$wwwui2 =~ s/(--accvar \S+) \S+ /$1 $class /;
    }

    return $wwwui2;
}
